==> unixodbc_2.1.1.orig.tar.gz: unixodbc-2.1.1.orig/ini/_iniScanUntilObject.c <==
/**********************************************************************************
 * _iniScanUntilObject
 *
 **************************************************
 * This code was created by Peter Harvey @ CodeByDesign.
 * Released under LGPL 28.JAN.99
 *
 * Contributions from...
 * -----------------------------------------------
 * Peter Harvey		- pharvey@codebydesign.com
 **************************************************/

#include "ini.h"

int _iniScanUntilObject( HINI hIni, FILE *hFile, char *pszLine )
{
	/* SCAN UNTIL WE GET TO AN OBJECT NAME OR EOF */
	pszLine[0] = '\0';
    while ( 1 )
    {
        if ( fgets( pszLine, INI_MAX_LINE, hFile ) == NULL )
        {
            return INI_NO_DATA;
        }
/*
printf( "[PAH][%s][%d] Line=[%s]\n", __FILE__, __LINE__, pszLine );
*/
        if ( pszLine[0] == hIni->cLeftBracket )
        {
			return INI_SUCCESS;
        }
        iniAllTrim( pszLine );
        if ( pszLine[0] == '\0' )
        {
            continue;
        }
        if ( pszLine[0] != hIni->cComment )
        {
			return INI_ERROR;
        }
    }

    return INI_SUCCESS;
}

int _iniScanUntilNextObject( HINI hIni, FILE *hFile, char *pszLine )
{
	/* SCAN UNTIL WE GET TO AN OBJECT NAME OR EOF, SKIPPING BODY */
	pszLine[0] = '\0';
    while ( 1 )
    {
        if ( fgets( pszLine, INI_MAX_LINE, hFile ) == NULL )
        {
            return INI_NO_DATA;
        }

        if ( pszLine[0] == hIni->cLeftBracket )
        {
			return INI_SUCCESS;
        }
    }

    return INI_SUCCESS;
}

==> unixodbc_2.3.6.orig.tar.gz: unixodbc-2.3.6/ini/_iniScanUntilObject.c <==
/**********************************************************************************
 * _iniScanUntilObject
 *
 **************************************************
 * This code was created by Peter Harvey @ CodeByDesign.
 * Released under LGPL 28.JAN.99
 *
 * Contributions from...
 * -----------------------------------------------
 * Peter Harvey		- pharvey@codebydesign.com
 **************************************************/

#include <config.h>
#include "ini.h"

int _iniScanUntilObject( HINI hIni, FILE *hFile, char *pszLine )
{
	/* SCAN UNTIL WE GET TO AN OBJECT NAME OR EOF */
	pszLine[0] = '\0';
    while ( 1 )
    {
        if ( uo_fgets( pszLine, INI_MAX_LINE, hFile ) == NULL )
        {
            return INI_NO_DATA;
        }
/*
printf( "[PAH][%s][%d] Line=[%s]\n", __FILE__, __LINE__, pszLine );
*/
        if ( pszLine[0] == hIni->cLeftBracket )
        {
			return INI_SUCCESS;
        }
        iniAllTrim( pszLine );
        if ( pszLine[0] == '\0' )
        {
            continue;
        }
        if ( strchr( hIni->cComment, pszLine[0] ) == NULL )
        {
			return INI_ERROR;
        }
    }

    return INI_SUCCESS;
}

int _iniScanUntilNextObject( HINI hIni, FILE *hFile, char *pszLine )
{
	/* SCAN UNTIL WE GET TO AN OBJECT NAME OR EOF, SKIPPING BODY */
	pszLine[0] = '\0';
    while ( 1 )
    {
        if ( uo_fgets( pszLine, INI_MAX_LINE, hFile ) == NULL )
        {
            return INI_NO_DATA;
        }

        if ( pszLine[0] == hIni->cLeftBracket )
        {
			return INI_SUCCESS;
        }
    }

    return INI_SUCCESS;
}
